0.9.9 API documentation: gradient_paint.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

gradient_paint.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18 #include "../gtx/optimum_pow.hpp"
19
20 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
21 # ifndef GLM_ENABLE_EXPERIMENTAL
22 # pragma message("GLM: GLM_GTX_gradient_paint is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
23 # else
24 # pragma message("GLM: GLM_GTX_gradient_paint extension included")
25 # endif
26 #endif
27
28 namespace glm
29 {
32
35 template<typename T, qualifier Q>
36 GLM_FUNC_DECL T radialGradient(
37 vec<2, T, Q> const& Center,
38 T const& Radius,
39 vec<2, T, Q> const& Focal,
40 vec<2, T, Q> const& Position);
41
44 template<typename T, qualifier Q>
45 GLM_FUNC_DECL T linearGradient(
46 vec<2, T, Q> const& Point0,
47 vec<2, T, Q> const& Point1,
48 vec<2, T, Q> const& Position);
49
51 }// namespace glm
52
53 #include "gradient_paint.inl"
glm::radialGradient
GLM_FUNC_DECL T radialGradient(vec< 2, T, Q > const &Center, T const &Radius, vec< 2, T, Q > const &Focal, vec< 2, T, Q > const &Position)
Return a color from a radial gradient.
glm::linearGradient
GLM_FUNC_DECL T linearGradient(vec< 2, T, Q > const &Point0, vec< 2, T, Q > const &Point1, vec< 2, T, Q > const &Position)
Return a color from a linear gradient.
glm
Definition: common.hpp:20